@@ -1,11 +1,8 @@
 use strict;
 use warnings;
 package Sys::HostIP;
-{
-  $Sys::HostIP::VERSION = '1.97';
-}
 # ABSTRACT: Try extra hard to get IP address related info
-
+$Sys::HostIP::VERSION = '1.98';
 use Carp;
 use Exporter;
 use File::Basename 'dirname';
@@ -268,7 +265,7 @@ sub _get_win32_interface_info {
             next;
         } elsif ( $line =~/^\s$/ ) {
             next;
-        } elsif ( ( $line =~ $regexes{'address'} ) and $interface ) {
+        } elsif ( ( $line =~ $regexes{'address'} ) and defined $interface ) {
             $if_info{$interface} = $1;
             $interface = undef;
         } elsif ( $line =~ $regexes{'adapter'} ) {
@@ -284,16 +281,6 @@ sub _get_win32_interface_info {
 
 __END__
 
-=pod
-
-=head1 NAME
-
-Sys::HostIP - Try extra hard to get IP address related info
-
-=head1 VERSION
-
-version 1.97
-
 =head1 SYNOPSIS
 
     use Sys::HostIP;
@@ -415,25 +402,3 @@ Machines with output in different languages (German, for example) fail.
 
 =back
 
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Sawyer X <xsawyerx@cpan.org>
-
-=item *
-
-Jonathan Schatz <jon@divisionbyzero.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2012 by Sawyer X.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
